@@ -78,9 +78,16 @@ class TransformersNER:
         logging.info(f'label2id: {self.label2id}')
         assert 'O' in self.label2id, f'invalid label2id {self.label2id}'
 
-        # GPU setup
-        self.device = 'cuda' if torch.cuda.device_count() > 0 else 'cpu'
+        # GPU setup https://github.com/asahi417/tner/issues/33
+        try:
+            # Mac M1 Support https://github.com/asahi417/tner/issues/30
+            self.device = 'mps' if torch.backends.mps.is_available() else 'cpu'
+        except Exception:
+            self.device = 'cpu'
+        if self.device == 'cpu':
+            self.device = 'cuda' if torch.cuda.device_count() > 0 else 'cpu'
         self.parallel = torch.cuda.device_count() > 1
+
         if self.parallel:
             self.model = torch.nn.DataParallel(self.model)
             if self.crf_layer is not None:
@@ -88,7 +95,8 @@ class TransformersNER:
         self.model.to(self.device)
         if self.crf_layer is not None:
             self.crf_layer.to(self.device)
-        logging.info(f'{torch.cuda.device_count()} GPUs are in use')
+        logging.info(f'device   : {self.device}')
+        logging.info(f'gpus     : {torch.cuda.device_count()}')
 
         # load pre processor
         if self.crf_layer is not None:
@@ -336,7 +344,7 @@ class TransformersNER:
             cache_file_feature=cache_file_feature,
             separator=separator
         )
-        return span_f1(output['prediction'], output['label'], self.label2id, span_detection_mode, return_ci=return_ci,
+        return span_f1(output['prediction'], output['label'], span_detection_mode, return_ci=return_ci,
                        unification_by_shared_label=unification_by_shared_label)
 
     def save(self, save_dir: str):
