@@ -3,6 +3,7 @@ import json
 import logging
 import random
 import gc
+import shutil
 from glob import glob
 from os.path import join as pj
 from typing import List, Dict
@@ -107,12 +108,17 @@ class Trainer:
             except Exception:
                 logging.exception(f'error at loading checkpoint {model_path}')
 
+        logging.info('hyperparameters')
+        for k, v in self.config.items():
+            logging.info(f'\t * {k}: {v}')
+
         # load dataset
         data, label2id = get_dataset(
             dataset=self.config['dataset'],
             local_dataset=self.config['local_dataset'],
             dataset_name=self.config['dataset_name'],
-            concat_label2id=self.model.label2id if self.model is not None else None
+            concat_label2id=self.model.label2id if self.model is not None else None,
+            use_auth_token=use_auth_token
         )
         assert self.config['dataset_split'] in data, f"split {self.config['dataset_split']} is not in {data.keys()}"
         self.dataset = data[self.config['dataset_split']]
@@ -136,10 +142,6 @@ class Trainer:
             with open(pj(self.checkpoint_dir, config_file), 'w') as f:
                 json.dump(self.config, f)
 
-        logging.info('hyperparameters')
-        for k, v in self.config.items():
-            logging.info(f'\t * {k}: {v}')
-
         random.seed(self.config['random_seed'])
         torch.manual_seed(self.config['random_seed'])
 
@@ -289,7 +291,7 @@ class GridSearcher:
                  dataset: List or str = None,
                  local_dataset: List or Dict = None,
                  dataset_split_train: str = 'train',
-                 dataset_split_valid: str = 'valid',
+                 dataset_split_valid: str = 'validation',
                  dataset_name: List or str = None,
                  model: str = 'roberta-large',
                  epoch: int = 10,
@@ -538,6 +540,7 @@ class GridSearcher:
             best_model_ckpt = f"{best_model_ckpt.split('epoch_')[0]}epoch_{config['epoch']}"
 
         copy_tree(best_model_ckpt, pj(self.checkpoint_dir, 'best_model'))
+        shutil.rmtree(pj(best_model_ckpt, 'eval'))
         with open(pj(self.checkpoint_dir, 'best_model', 'trainer_config.json'), 'w') as f:
             json.dump(config, f)
 
